# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`virtualbox`](#virtualbox): Installs VirtualBox.

#### Private Classes

* `virtualbox::install`: installs the VirtualBox package
* `virtualbox::kernel`: compiles and installs the VirtualBox kernel modules
* `virtualbox::params`: It sets variables according to platform

### Defined types

* [`virtualbox::extpack`](#virtualboxextpack): This class (un)installs Oracle's VirtualBox extension pack.

## Classes

### <a name="virtualbox"></a>`virtualbox`

Installs VirtualBox.

#### Parameters

The following parameters are available in the `virtualbox` class:

* [`version`](#version)
* [`package_ensure`](#package_ensure)
* [`manage_repo`](#manage_repo)
* [`manage_ext_repo`](#manage_ext_repo)
* [`repo_proxy`](#repo_proxy)
* [`manage_package`](#manage_package)
* [`manage_kernel`](#manage_kernel)
* [`vboxdrv_dependencies`](#vboxdrv_dependencies)
* [`package_name`](#package_name)

##### <a name="version"></a>`version`

Data type: `String`

The major version of the package to install.

Default value: `'6.0'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

This gets passed to the package resource as the value of the 'ensure'
parameter. This can be used to specify a package version.

Default value: `'present'`

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Should this module manage the package repository?
Defaults to true

Default value: `$virtualbox::params::manage_repo`

##### <a name="manage_ext_repo"></a>`manage_ext_repo`

Data type: `Boolean`

On applicable platforms, should this module manage the external dependency
repository when `manage_kernel` is set to true?
Defaults to true

Default value: ``true``

##### <a name="repo_proxy"></a>`repo_proxy`

Data type: `Optional[String]`

proxy used by yum

Default value: ``undef``

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Should this module manage the package?
Defaults to true

Default value: ``true``

##### <a name="manage_kernel"></a>`manage_kernel`

Data type: `Boolean`

Should this module install the VirtualBox kernel modules?
Defaults to true

Default value: ``true``

##### <a name="vboxdrv_dependencies"></a>`vboxdrv_dependencies`

Data type: `Array`

Dependencies for building the VirtualBox kernel modules.
Defaults depend on the platform. See virtualbox::params.

Default value: `$virtualbox::params::vboxdrv_dependencies`

##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the package to install. This must be the full packge name when
not the default. When the default is in use, it gets compounded with the
major.minor components of the version number.
Defaults to 'VirtualBox' for RedHat and 'virtualbox' for Debian

Default value: `$virtualbox::params::package_name`

## Defined types

### <a name="virtualboxextpack"></a>`virtualbox::extpack`

This class (un)installs Oracle's VirtualBox extension pack.

#### Parameters

The following parameters are available in the `virtualbox::extpack` defined type:

* [`source`](#source)
* [`ensure`](#ensure)
* [`verify_checksum`](#verify_checksum)
* [`checksum_string`](#checksum_string)
* [`checksum_type`](#checksum_type)
* [`extpack_path`](#extpack_path)

##### <a name="source"></a>`source`

Data type: `String`

Download extension pack from the given URL. Required string.

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Set to 'present' to install extension pack. Set to 'absent' to uninstall.
Defaults to 'present'

Default value: `'present'`

##### <a name="verify_checksum"></a>`verify_checksum`

Data type: `Boolean`

Whether to verify the checksum of the downloaded file. Optional boolean.
Defaults to true.

Default value: ``true``

##### <a name="checksum_string"></a>`checksum_string`

Data type: `Optional[String]`

If $verify_checksum is true, this is the checksum to use to validate the
downloaded file against.

Default value: ``undef``

##### <a name="checksum_type"></a>`checksum_type`

Data type: `Enum['md5', 'sha1', 'sha224', 'sha256', 'sha384', 'sha512']`

If $verify_checksum is true, this is the algorithm to use to validate the
checksum. Can be md5, sha1, sha224, sha256, sha384, or sha512. Defaults to
'md5'

Default value: `'md5'`

##### <a name="extpack_path"></a>`extpack_path`

Data type: `Stdlib::Absolutepath`

This is the path where VirtualBox looks for extension packs. Defaults to
'/usr/lib/virtualbox/ExtensionPacks'

Default value: `'/usr/lib/virtualbox/ExtensionPacks'`

